@@ -289,7 +289,7 @@ class TftpServerHandler(TftpSession):
                 self.filename = os.path.abspath(self.filename)
                 logger.debug("The absolute path is %s" % self.filename)
                 # Security check. Make sure it's prefixed by the tftproot.
-                if re.match(r'%s' % self.root, self.filename):
+                if self.filename.find(self.root) == 0:
                     logger.debug("The path appears to be safe: %s" %
                             self.filename)
                 else:
@@ -322,18 +322,13 @@ class TftpServerHandler(TftpSession):
 
                         self.send_oack()
 
-                    elif len(recvpkt.options.keys()) > 0:
-                        logger.warning("Client %s requested unsupported options: %s"
-                                % (self.key, recvpkt.options))
-                        logger.warning("Responding with negotiation error")
-                        self.senderror(self.sock,
-                                       TftpErrors.FailedNegotiation,
-                                       self.host,
-                                       self.port)
-                        raise TftpException, "Failed option negotiation"
-
                     else:
-                        logger.debug("Client %s requested no options."
+                        if len(recvpkt.options.keys()) > 0:
+                            logger.warning("Client %s requested unsupported options: %s"
+                                % (self.key, recvpkt.options))
+                            logger.debug("Ignoring options, responding with DAT")
+                        else:
+                            logger.debug("Client %s requested no options."
                                 % self.key)
                         self.start_download()
 
@@ -401,7 +396,7 @@ class TftpServerHandler(TftpSession):
         """This method opens self.filename, stores the resulting file object
         in self.fileobj, and calls send_dat()."""
         self.state.state = 'dat'
-        self.fileobj = open(self.filename, "r")
+        self.fileobj = open(self.filename, "rb")
         self.send_dat()
 
     def send_dat(self, resend=False):
